==> thunderbird_66.0~b1.orig.tar.xz: thunderbird-66.0/browser/components/newtab/prerendered/locales/es-MX/activity-stream-strings.js <==
// Note - this is a generated es-MX file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nueva pestaña",
  "header_top_sites": "Sitios favoritos",
  "header_highlights": "Destacados",
  "header_recommended_by": "Recomendado por {provider}",
  "context_menu_button_sr": "Abrir menú contextual para {title}",
  "section_context_menu_button_sr": "Abrir la sección menú contextual",
  "type_label_visited": "Visitados",
  "type_label_bookmarked": "En marcadores",
  "type_label_recommended": "Tendencias",
  "type_label_pocket": "Guardado en Pocket",
  "type_label_downloaded": "Descargado",
  "menu_action_bookmark": "Marcador",
  "menu_action_remove_bookmark": "Eliminar marcador",
  "menu_action_open_new_window": "Abrir en una nueva ventana",
  "menu_action_open_private_window": "Abrir en una nueva ventana privada",
  "menu_action_dismiss": "Descartar",
  "menu_action_delete": "Eliminar del historial",
  "menu_action_pin": "Anclar",
  "menu_action_unpin": "Desanclar",
  "confirm_history_delete_p1": "¿Estás seguro de que quieres eliminar de tu historial todas las instancias de esta página?",
  "confirm_history_delete_notice_p2": "Esta acción no se puede deshacer.",
  "menu_action_save_to_pocket": "Guardar en Pocket",
  "menu_action_delete_pocket": "Eliminar de Pocket",
  "menu_action_archive_pocket": "Archivar en Pocket",
  "menu_action_show_file_mac_os": "Mostrar en Finder",
  "menu_action_show_file_windows": "Abrir carpeta contenedora",
  "menu_action_show_file_linux": "Abrir carpeta contenedora",
  "menu_action_show_file_default": "Mostrar archivo",
  "menu_action_open_file": "Abrir archivo",
  "menu_action_copy_download_link": "Copiar enlace de descarga",
  "menu_action_go_to_download_page": "Ir a la página de descarga",
  "menu_action_remove_download": "Eliminar del historial",
  "search_button": "Buscar",
  "search_header": "Buscar con {search_engine_name}",
  "search_web_placeholder": "Buscar en la Web",
  "section_disclaimer_topstories": "Las más interesantes historias en la web, seleccionadas basándonos en los que lees. Desde Pocket, ahora parte de Mozilla.",
  "section_disclaimer_topstories_linktext": "Saber cómo funciona.",
  "section_disclaimer_topstories_buttontext": "Está bien, lo entiendo",
  "prefs_home_header": "Contenido de la página de inicio de Firefox",
  "prefs_home_description": "Selecciona el contenido que desea en la pantalla de inicio de Firefox.",
  "prefs_content_discovery_header": "Página de inicio de Firefox",
  "prefs_content_discovery_description": "Content Discovery en la página de inicio de Firefox le permite descubrir artículos relevantes de alta calidad en toda la web.",
  "prefs_content_discovery_button": "Desactivar Content Discovery",
  "prefs_section_rows_option": "{num} fila;{num} filas",
  "prefs_search_header": "Búsqueda web",
  "prefs_topsites_description": "Los sitios que más visitas",
  "prefs_topstories_description2": "El mejor contenido de la web, personalizado para ti",
  "prefs_topstories_options_sponsored_label": "Artículos patrocinados",
  "prefs_topstories_sponsored_learn_more": "Saber más",
  "prefs_highlights_description": "Una selección de sitios que has guardado o visitado",
  "prefs_highlights_options_visited_label": "Páginas visitadas",
  "prefs_highlights_options_download_label": "Descargado recientemente",
  "prefs_highlights_options_pocket_label": "Páginas guardadas en Pocket",
  "prefs_snippets_description": "Actualizaciones de Mozilla y Firefox",
  "settings_pane_button_label": "Personalizar tu página de nueva pestaña",
  "settings_pane_topsites_header": "Sitios populares",
  "settings_pane_highlights_header": "Destacados",
  "settings_pane_highlights_options_bookmarks": "Marcadores",
  "settings_pane_snippets_header": "Fragmentos",
  "edit_topsites_button_text": "Editar",
  "edit_topsites_edit_button": "Editar este sitio",
  "topsites_form_add_header": "Nuevo sitio popular",
  "topsites_form_edit_header": "Editar sitio popular",
  "topsites_form_title_label": "Título",
  "topsites_form_title_placeholder": "Introducir un título",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL de imagen personalizada",
  "topsites_form_url_placeholder": "Escribir o pegar una URL",
  "topsites_form_use_image_link": "Utilizar una imagen personalizada…",
  "topsites_form_preview_button": "Vista previa",
  "topsites_form_add_button": "Agregar",
  "topsites_form_save_button": "Guardar",
  "topsites_form_cancel_button": "Cancelar",
  "topsites_form_url_validation": "Se requiere una URL válida",
  "topsites_form_image_validation": "La imagen no se pudo cargar. Intente una URL diferente.",
  "pocket_read_more": "Temas populares:",
  "pocket_read_even_more": "Ver más historias",
  "pocket_more_reccommendations": "Más recomendaciones",
  "pocket_how_it_works": "Cómo funciona",
  "pocket_cta_button": "Obtener Pocket",
  "pocket_cta_text": "Guarda las historias que quieras en Pocket y llena tu mente con fascinantes lecturas.",
  "highlights_empty_state": "Empieza a navegar, y nosotros te mostraremos aquí algunos de los mejores artículos, videos y otras páginas que hayas visitado recientemente o marcado.",
  "topstories_empty_state": "Ya estás al día. Vuelve luego y busca más historias de {provider}. ¿No puedes esperar? Selecciona un tema popular y encontrarás más historias interesantes por toda la web.",
  "manual_migration_explanation2": "Prueba Firefox con los marcadores, historial y contraseñas de otro navegador.",
  "manual_migration_cancel_button": "No, gracias",
  "manual_migration_import_button": "Importar ahora",
  "error_fallback_default_info": "Ups, algo salió mal mientras se cargaba el contenido.",
  "error_fallback_default_refresh_suggestion": "Actualiza la página e intenta de nuevo.",
  "section_menu_action_remove_section": "Eliminar sección",
  "section_menu_action_collapse_section": "Sección de colapso",
  "section_menu_action_expand_section": "Ampliar la sección",
  "section_menu_action_manage_section": "Administrar sección",
  "section_menu_action_manage_webext": "Gestionar extensión",
  "section_menu_action_add_topsite": "Agregar sitio popular",
  "section_menu_action_add_search_engine": "Agregar motor de búsqueda",
  "section_menu_action_move_up": "Subir",
  "section_menu_action_move_down": "Bajar",
  "section_menu_action_privacy_notice": "Política de privacidad",
  "firstrun_title": "Lleva a Firefox contigo",
  "firstrun_content": "Accede a tus marcadores, historial, contraseñas y más ajustes en todos tus dispositivos.",
  "firstrun_learn_more_link": "Conoce más acerca de Firefox Accounts",
  "firstrun_form_header": "Ingresa tu correo electrónico",
  "firstrun_form_sub_header": "para acceder a Firefox Sync.",
  "firstrun_email_input_placeholder": "Correo electrónico",
  "firstrun_invalid_input": "Se requiere un correo válido",
  "firstrun_extra_legal_links": "Al proceder, aceptas los {terms} y la {privacy}.",
  "firstrun_terms_of_service": "Términos del servicio",
  "firstrun_privacy_notice": "Política de privacidad",
  "firstrun_continue_to_login": "Continuar",
  "firstrun_skip_login": "Saltar este paso",
  "context_menu_title": "Abrir menú",
  "pocket_learn_more": "Saber más"
};

==> thunderbird_68.10.0.orig.tar.xz: thunderbird-68.10.0/browser/components/newtab/prerendered/locales/es-MX/activity-stream-strings.js <==
// Note - this is a generated es-MX file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nueva pestaña",
  "header_top_sites": "Sitios favoritos",
  "header_highlights": "Destacados",
  "header_recommended_by": "Recomendado por {provider}",
  "context_menu_button_sr": "Abrir menú contextual para {title}",
  "section_context_menu_button_sr": "Abrir la sección menú contextual",
  "type_label_visited": "Visitados",
  "type_label_bookmarked": "En marcadores",
  "type_label_recommended": "Tendencias",
  "type_label_pocket": "Guardado en Pocket",
  "type_label_downloaded": "Descargado",
  "menu_action_bookmark": "Marcador",
  "menu_action_remove_bookmark": "Eliminar marcador",
  "menu_action_open_new_window": "Abrir en una nueva ventana",
  "menu_action_open_private_window": "Abrir en una nueva ventana privada",
  "menu_action_dismiss": "Descartar",
  "menu_action_delete": "Eliminar del historial",
  "menu_action_pin": "Anclar",
  "menu_action_unpin": "Desanclar",
  "confirm_history_delete_p1": "¿Estás seguro de que quieres eliminar de tu historial todas las instancias de esta página?",
  "confirm_history_delete_notice_p2": "Esta acción no se puede deshacer.",
  "menu_action_save_to_pocket": "Guardar en Pocket",
  "menu_action_delete_pocket": "Eliminar de Pocket",
  "menu_action_archive_pocket": "Archivar en Pocket",
  "menu_action_show_file_mac_os": "Mostrar en Finder",
  "menu_action_show_file_windows": "Abrir carpeta contenedora",
  "menu_action_show_file_linux": "Abrir carpeta contenedora",
  "menu_action_show_file_default": "Mostrar archivo",
  "menu_action_open_file": "Abrir archivo",
  "menu_action_copy_download_link": "Copiar enlace de descarga",
  "menu_action_go_to_download_page": "Ir a la página de descarga",
  "menu_action_remove_download": "Eliminar del historial",
  "search_button": "Buscar",
  "search_header": "Buscar con {search_engine_name}",
  "search_web_placeholder": "Buscar en la Web",
  "section_disclaimer_topstories": "Las más interesantes historias en la web, seleccionadas basándonos en los que lees. Desde Pocket, ahora parte de Mozilla.",
  "section_disclaimer_topstories_linktext": "Saber cómo funciona.",
  "section_disclaimer_topstories_buttontext": "Está bien, lo entiendo",
  "prefs_home_header": "Contenido de la página de inicio de Firefox",
  "prefs_home_description": "Selecciona el contenido que desea en la pantalla de inicio de Firefox.",
  "prefs_content_discovery_description": "Content Discovery en la página de inicio de Firefox le permite descubrir artículos de alta calidad y relevantes de toda la web.",
  "prefs_section_rows_option": "{num} fila;{num} filas",
  "prefs_search_header": "Búsqueda web",
  "prefs_topsites_description": "Los sitios que más visitas",
  "prefs_topstories_description2": "El mejor contenido de la web, personalizado para ti",
  "prefs_topstories_options_sponsored_label": "Artículos patrocinados",
  "prefs_topstories_sponsored_learn_more": "Saber más",
  "prefs_highlights_description": "Una selección de sitios que has guardado o visitado",
  "prefs_highlights_options_visited_label": "Páginas visitadas",
  "prefs_highlights_options_download_label": "Descargado recientemente",
  "prefs_highlights_options_pocket_label": "Páginas guardadas en Pocket",
  "prefs_snippets_description": "Actualizaciones de Mozilla y Firefox",
  "settings_pane_button_label": "Personalizar tu página de nueva pestaña",
  "settings_pane_topsites_header": "Sitios populares",
  "settings_pane_highlights_header": "Destacados",
  "settings_pane_highlights_options_bookmarks": "Marcadores",
  "settings_pane_snippets_header": "Fragmentos",
  "edit_topsites_button_text": "Editar",
  "edit_topsites_edit_button": "Editar este sitio",
  "topsites_form_add_header": "Nuevo sitio popular",
  "topsites_form_edit_header": "Editar sitio popular",
  "topsites_form_title_label": "Título",
  "topsites_form_title_placeholder": "Introducir un título",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL de imagen personalizada",
  "topsites_form_url_placeholder": "Escribir o pegar una URL",
  "topsites_form_use_image_link": "Utilizar una imagen personalizada…",
  "topsites_form_preview_button": "Vista previa",
  "topsites_form_add_button": "Agregar",
  "topsites_form_save_button": "Guardar",
  "topsites_form_cancel_button": "Cancelar",
  "topsites_form_url_validation": "Se requiere una URL válida",
  "topsites_form_image_validation": "La imagen no se pudo cargar. Intente una URL diferente.",
  "pocket_read_more": "Temas populares:",
  "pocket_read_even_more": "Ver más historias",
  "pocket_more_reccommendations": "Más recomendaciones",
  "pocket_how_it_works": "Cómo funciona",
  "pocket_cta_button": "Obtener Pocket",
  "pocket_cta_text": "Guarda las historias que quieras en Pocket y llena tu mente con fascinantes lecturas.",
  "highlights_empty_state": "Empieza a navegar, y nosotros te mostraremos aquí algunos de los mejores artículos, videos y otras páginas que hayas visitado recientemente o marcado.",
  "topstories_empty_state": "Ya estás al día. Vuelve luego y busca más historias de {provider}. ¿No puedes esperar? Selecciona un tema popular y encontrarás más historias interesantes por toda la web.",
  "error_fallback_default_info": "Ups, algo salió mal mientras se cargaba el contenido.",
  "error_fallback_default_refresh_suggestion": "Actualiza la página e intenta de nuevo.",
  "section_menu_action_remove_section": "Eliminar sección",
  "section_menu_action_collapse_section": "Sección de colapso",
  "section_menu_action_expand_section": "Ampliar la sección",
  "section_menu_action_manage_section": "Administrar sección",
  "section_menu_action_manage_webext": "Gestionar extensión",
  "section_menu_action_add_topsite": "Agregar sitio popular",
  "section_menu_action_add_search_engine": "Agregar motor de búsqueda",
  "section_menu_action_move_up": "Subir",
  "section_menu_action_move_down": "Bajar",
  "section_menu_action_privacy_notice": "Política de privacidad",
  "firstrun_title": "Lleva a Firefox contigo",
  "firstrun_content": "Accede a tus marcadores, historial, contraseñas y más ajustes en todos tus dispositivos.",
  "firstrun_learn_more_link": "Conoce más acerca de Firefox Accounts",
  "firstrun_form_header": "Ingresa tu correo electrónico",
  "firstrun_form_sub_header": "para acceder a Firefox Sync.",
  "firstrun_email_input_placeholder": "Correo electrónico",
  "firstrun_invalid_input": "Se requiere un correo válido",
  "firstrun_extra_legal_links": "Al proceder, aceptas los {terms} y la {privacy}.",
  "firstrun_terms_of_service": "Términos del servicio",
  "firstrun_privacy_notice": "Política de privacidad",
  "firstrun_continue_to_login": "Continuar",
  "firstrun_skip_login": "Saltar este paso",
  "context_menu_title": "Abrir menú"
};
